-- Copyright (c) 2014 Sebastian Wiesner <lunaryorn@gmail.com>

-- Permission is hereby granted, free of charge, to any person obtaining a copy
-- of this software and associated documentation files (the "Software"), to deal
-- in the Software without restriction, including without limitation the rights
-- to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-- copies of the Software, and to permit persons to whom the Software is
-- furnished to do so, subject to the following conditions:

-- The above copyright notice and this permission notice shall be included in
-- all copies or substantial portions of the Software.

-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-- IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-- FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-- AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-- LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-- OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-- THE SOFTWARE.

{-# LANGUAGE DeriveDataTypeable #-}

-- |Guess the file type of files.
module System.IO.Magic where

import Control.Exception (Exception,throwIO)
import Data.Typeable (Typeable)
import System.Exit(ExitCode(..))
import System.Process (readProcessWithExitCode)

newtype MagicException = MagicException String
                       deriving Typeable

instance Show MagicException where
  show (MagicException message) = message

instance Exception MagicException

guessMimeType :: FilePath -> IO String
guessMimeType fileName = do
  (status, stdout, stderr) <- readProcessWithExitCode "file" args []
  case status of
    ExitFailure _ -> throwIO (MagicException (stdout ++ stderr))
    ExitSuccess -> return (head (lines stdout))
  where args = ["--brief", "--mime-type", fileName]
